@@ -50,9 +50,6 @@ import "node";
 import "size";
 import "enter";
 
-import "transition";
-import "interrupt";
-
 // TODO fast singleton implementation?
 d3.select = function(node) {
   var group = [typeof node === "string" ? d3_select(node, d3_document) : node];
