@@ -26,6 +26,11 @@ module.exports = function() {
     return topic;
   };
 
+  topic.sandbox = function(_) {
+    sandbox = _;
+    return topic;
+  };
+
   topic.document = function(_) {
     var document = jsdom.jsdom("<html><head></head><body></body></html>");
 
@@ -41,7 +46,7 @@ module.exports = function() {
       console: console,
       XMLHttpRequest: XMLHttpRequest,
       document: document,
-      window: document.createWindow(),
+      window: document.parentWindow,
       setTimeout: setTimeout,
       clearTimeout: clearTimeout,
       Date: Date // so we can override Date.now in tests, and use deepEqual
